#container .toolbar {
  padding-bottom: 15px;
}
#container #notifications p {
  padding: 10px;
  margin: 1em 0;
  border-width: 1px;
  border-style: solid;
}
#container #notifications p.error {
  color: #8a1f11;
  background-color: #fbe3e4;
  border-color: #fbc2c4;
}
#container #notifications p.success {
  color: #264409;
  background-color: #e6efc2;
  border-color: #c6d880;
}
#container ul.switches {
  list-style-image: none;
  list-style-type: none;
  margin-left: 0;
}
#container ul.switches > li {
  padding: 15px 10px;
}
#container ul.switches > li + li {
  border-top: 1px solid #DFDFDF;
}
#container ul.switches > li > form {
  overflow: hidden;
  *zoom: 1;
  clear: both;
  margin-top: 20px;
}
#container ul.switches > li > form ul.errorlist {
  color: #8a1f11;
  font-weight: bold;
  margin-left: 105px;
}
#container ul.switches > li > form label {
  display: inline;
  float: left;
  display: block;
  font-weight: bold;
  margin-right: 5px;
  text-align: right;
  width: 100px;
}
#container ul.switches > li > form input[type=text] {
  width: 200px;
}
#container ul.switches > li > form input[name=name] {
  font-size: 1.5em;
  width: 600px;
}
#container ul.switches > li > form input[type=submit] {
  margin-left: 100px;
}
#container ul.switches > li > form textarea {
  width: 350px;
  height: 50px;
}
#container ul.switches > li > form button {
  padding: 3px 8px;
}
#container ul.switches > li > form button[data-action=add] {
  margin-left: 105px;
}
#container ul.switches > li > form section.conditions {
  background: #F9F9F9;
  padding: 10px 0;
}
#container ul.switches > li > form ul.conditions {
  list-style-image: none;
  list-style-type: none;
  margin-left: 0;
  margin-left: 105px;
}
#container ul.switches > li > form ul.conditions input {
  width: 100px;
}
#container ul.switches > li > form ul.conditions li {
  overflow: hidden;
  *zoom: 1;
}
#container ul.switches > li > form ul.conditions li + li {
  margin-top: 5px;
}
#container ul.switches > li > form ul.conditions label {
  display: none;
}
#container ul.switches > li > form ul.conditions section.condition, #container ul.switches > li > form ul.conditions button {
  display: inline;
  float: left;
}
#container ul.switches > li > form ul.conditions .added, #container ul.switches > li > form ul.conditions button {
  margin-left: 4px;
}
#container ul.switches > li > form section.actions {
  margin-top: 20px;
}
